/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2017  SEGGER Microcontroller GmbH & Co. KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V5.46 - Graphical user interface for embedded applications **
All  Intellectual Property rights  in the Software belongs to  SEGGER.
emWin is protected by  international copyright laws.  Knowledge of the
source code may not be used to write a similar product.  This file may
only be used in accordance with the following terms:

The software has been licensed to  ARM LIMITED whose registered office
is situated at  110 Fulbourn Road,  Cambridge CB1 9NJ,  England solely
for  the  purposes  of  creating  libraries  for  ARM7, ARM9, Cortex-M
series,  and   Cortex-R4   processor-based  devices,  sublicensed  and
distributed as part of the  MDK-ARM  Professional  under the terms and
conditions  of  the   End  User  License  supplied  with  the  MDK-ARM
Professional. 
Full source code is available at: www.segger.com

We appreciate your understanding and fairness.
----------------------------------------------------------------------
Licensing information
Licensor:                 SEGGER Software GmbH
Licensed to:              ARM Ltd, 110 Fulbourn Road, CB1 9NJ Cambridge, UK
Licensed SEGGER software: emWin
License number:           GUI-00181
License model:            LES-SLA-20007, Agreement, effective since October 1st 2011 
Licensed product:         MDK-ARM Professional
Licensed platform:        ARM7/9, Cortex-M/R4
Licensed number of seats: -
----------------------------------------------------------------------
File        : LCDConf.c
Purpose     : Display controller configuration (single layer)
---------------------------END-OF-HEADER------------------------------
*/

#include "GUI.h"
#include "GUIDRV_FlexColor.h"
#include "pin_mux.h"
#include "fsl_common.h"
#include "fsl_iomuxc.h"
#include "LCD_X_SPI.h"
#include "fsl_gpio.h"

/*********************************************************************
*
*       Layer configuration (to be modified)
*
**********************************************************************
*/
//
// Physical display size
//   The display size should be adapted in order to match the size of
//   the target display.
//
#define XSIZE_PHYS 320
#define YSIZE_PHYS 240

//
// Color conversion
//   The color conversion functions should be selected according to
//   the color mode of the target display. Detaileds can be found in
//   the chapter "Colors" in the emWin user manual.
//
#define COLOR_CONVERSION GUICC_565

//
// Display driver
//   GUIDRV_WIN32 is for use only within the emWin Simulation
//   environment. In order to use the target display controller, the
//   according emWin display driver should be configured as it is
//   described in the chapter "Display Drivers" in the emWin user
//   manual. Beyond that sample configuration files can be found in
//   The folder "Sample\LCDConf\%DISPLAY_DRIVER%\".
//
#define DISPLAY_DRIVER GUIDRV_FLEXCOLOR

#define DISPLAY_ORIENTATION ( GUI_SWAP_XY )
//#define DISPLAY_ORIENTATION ( 0U )

//#define DISPLAY_ORIENTATION 0U
#ifndef   VXSIZE_PHYS
  #define VXSIZE_PHYS XSIZE_PHYS
#endif
#ifndef   VYSIZE_PHYS
  #define VYSIZE_PHYS YSIZE_PHYS
#endif

/*********************************************************************
*
*       Configuration checking
*
**********************************************************************
*/
#ifndef   XSIZE_PHYS
  #error Physical X size of display is not defined!
#endif
#ifndef   YSIZE_PHYS
  #error Physical Y size of display is not defined!
#endif
#ifndef   COLOR_CONVERSION
  #error Color conversion not defined!
#endif
#ifndef   DISPLAY_DRIVER
  #error No display driver defined!
#endif

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       LCD_X_Config
*
* Function description
*   Called during the initialization process in order to set up the
*   display driver configuration.
*/
void LCD_X_Config(void) {
//  //
//  // Set display driver and color conversion for 1st layer
//  //
//  GUI_DEVICE_CreateAndLink(DISPLAY_DRIVER, COLOR_CONVERSION, 0, 0);
//  //
//  // Display driver configuration
//  //
//  if (LCD_GetSwapXY()) {
//    LCD_SetSizeEx (0, YSIZE_PHYS, XSIZE_PHYS);
//    LCD_SetVSizeEx(0, YSIZE_PHYS, XSIZE_PHYS);
//  } else {
//    LCD_SetSizeEx (0, XSIZE_PHYS, YSIZE_PHYS);
//    LCD_SetVSizeEx(0, XSIZE_PHYS, YSIZE_PHYS);
	 GUI_DEVICE * pDevice;
  GUI_PORT_API PortAPI = {0};
  CONFIG_FLEXCOLOR Config = {0};

  //
  // Set display driver and color conversion for 1st layer
  //
  pDevice = GUI_DEVICE_CreateAndLink(DISPLAY_DRIVER, COLOR_CONVERSION, 0, 0);
  //
  // Display driver configuration
  //
  if (DISPLAY_ORIENTATION & GUI_SWAP_XY) {
    LCD_SetSizeEx (0, YSIZE_PHYS,   XSIZE_PHYS);
    LCD_SetVSizeEx(0, VYSIZE_PHYS,  VXSIZE_PHYS);
  } else {
    LCD_SetSizeEx (0, XSIZE_PHYS,   YSIZE_PHYS);
    LCD_SetVSizeEx(0, VXSIZE_PHYS,  VYSIZE_PHYS);
  }
  //
  // Function selection, hardware routines (PortAPI) and operation mode (bus, bpp and cache)
  //
  PortAPI.pfWrite8_A0  = LCD_X_SPI_Write_CMD;
  PortAPI.pfWrite8_A1  = LCD_X_SPI_Write_DATA;	
	PortAPI.pfWriteM8_A1 = LCD_X_SPI_Multiple_Write_DATA;
	PortAPI.pfReadM8_A1 = LCD_X_SPI_Multiple_Read_DATA;
	

  GUIDRV_FlexColor_SetFunc(pDevice, &PortAPI, GUIDRV_FLEXCOLOR_F66709, GUIDRV_FLEXCOLOR_M16C0B8);
  //
  // Orientation
  //
  Config.Orientation = DISPLAY_ORIENTATION;
  GUIDRV_FlexColor_Config(pDevice, &Config);
  }

/*********************************************************************
*
*       LCD_X_DisplayDriver
*
* Function description
*   Display driver callback function. This function is called by the
*   Display driver for certain purposes. Using GUIDRV_Win32 it is not
*   required to react to any command.
*/
	
	 void _InitController(void) {
	SSP1_CS_High();
	TFT_RST_Pin_Low();
	GUI_X_Delay(255);
	TFT_RST_Pin_High();
	GUI_X_Delay(500);

	TFT_DC_Pin_High();

	LCD_X_SPI_Write_CMD(0x01); //Soft Reset
  GUI_X_Delay(30);
  LCD_X_SPI_Write_CMD(0x28); //Display OFF

  LCD_X_SPI_Write_CMD(0xf7);
  LCD_X_SPI_Write_DATA(0x20);

  LCD_X_SPI_Write_CMD(0xea);
  LCD_X_SPI_Write_DATA(0x00);
  LCD_X_SPI_Write_DATA(0x00);

  LCD_X_SPI_Write_CMD(0xc0); //PWCTR1
  LCD_X_SPI_Write_DATA(0x26);    //VRH: 4.75V

  LCD_X_SPI_Write_CMD(0xc1); //PWCTR2
  LCD_X_SPI_Write_DATA(0x11);    //AVDD: VCIx2, VGH: VCIx7, VGL: -VCIx3

  LCD_X_SPI_Write_CMD(0xc5); //VMCTR1
  LCD_X_SPI_Write_DATA(0x35);    //4.025V VCOMH
  LCD_X_SPI_Write_DATA(0x3e);    //-0.95V VCOML

  LCD_X_SPI_Write_CMD(0xc7); //VMCTR2
  LCD_X_SPI_Write_DATA(0xbe);    //VMF: VMH2, VML2

  LCD_X_SPI_Write_CMD(0x3a); //Pixel Format Set
  //LCD_X_SPI_Write_DATA(0x55);    //
	LCD_X_SPI_Write_DATA(0x05);

  LCD_X_SPI_Write_CMD(0xb1); //Frame Control (Normal mode)
  LCD_X_SPI_Write_DATA(0x00);    //Default: 0x00
  LCD_X_SPI_Write_DATA(0x1B);    //Default: 0x1B

  LCD_X_SPI_Write_CMD(0x26); //Gamma Set
  LCD_X_SPI_Write_DATA(0x01);    //Default: 0x01

  LCD_X_SPI_Write_CMD(0x11); //Sleep OUT
  GUI_X_Delay(100);
  LCD_X_SPI_Write_CMD(0x29); //Display ON
  GUI_X_Delay(100);
	
}
int LCD_X_DisplayDriver(unsigned LayerIndex, unsigned Cmd, void * pData) {
	int r;
  GUI_USE_PARA(LayerIndex);
//  GUI_USE_PARA(Cmd);
  GUI_USE_PARA(pData);
	  switch (Cmd) {
  //
  // Required
  //
  case LCD_X_INITCONTROLLER: {
    //
    // Called during the initialization process in order to set up the
    // display controller and put it into operation. If the display
    // controller is not initialized by any external routine this needs
    // to be adapted by the customer...
    //
    _InitController();
    return 0;
  }
//	case 2:
//		return 0;
  default:
    r = -1;
  }
  return r;
  //return 0;
}

/*************************** End of file ****************************/
