#include "LCD_X_SPI.h"
#include "GUI.h"
#include "board.h"
#include "fsl_gpio.h"
#include "fsl_lpspi_cmsis.h"

#define BUFFER_SIZE							(1)
#define TRANSFER_SIZE 64U         /* Transfer dataSize */
#define EXAMPLE_LPSPI_DEALY_COUNT 0xfffffU


#define DRIVER_MASTER_SPI Driver_SPI1
//AT_NONCACHEABLE_SECTION_INIT(uint8_t masterRxData[TRANSFER_SIZE]) = {0};
//AT_NONCACHEABLE_SECTION_INIT(uint8_t masterTxData[TRANSFER_SIZE]) = {0};
extern uint8_t masterRxData[];
extern uint8_t masterTxData[];


extern volatile bool isTransferCompleted;
extern volatile bool isMasterOnReceive;

void SSP1_CS_Low()
{
	GPIO_PinWrite(GPIO3, 13, 0U);
}

/*
 * Set Chip Select of SSP1 to High
 */
void SSP1_CS_High()
{
	GPIO_PinWrite(GPIO3, 13, 1U);
}

/*
 *  Set pin that is connected to lcd d/c pin to Low
 */
void TFT_DC_Pin_Low()
{
	GPIO_PinWrite(GPIO1, 20, 0U);
}

/*
 * Set pin that is connected to lcd d/c pin to High
 */
void TFT_DC_Pin_High()
{
	GPIO_PinWrite(GPIO1, 20, 1U);
}

/*
 *  Set pin that is connected to lcd reset pin to Low
 */
void TFT_RST_Pin_Low()
{
	GPIO_PinWrite(GPIO1, 17, 0U);
}

/*
 *  Set pin that is connected to lcd reset pin to High
 */
void TFT_RST_Pin_High()
{
	GPIO_PinWrite(GPIO1, 17, 1U);
}

/*********************************************************************
*
*       LCD_X_SPI_Write_CMD
*
* Purpose:
*   Write command to controller
*/
//void LCD_X_SPI_Write_CMD (U8 cmd) {

//  TFT_DC_Pin_Low();
//	LCD_Writ_Bus(da);
//}


 void LCD_WR_DATA(int da)
{
  TFT_DC_Pin_High();
	LCD_X_SPI_Write_DATA(da>>8);
	LCD_X_SPI_Write_DATA(da);
}	 

void Address_set(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2)
{  
   LCD_X_SPI_Write_CMD(0x2a);
   LCD_X_SPI_Write_DATA(x1>>8);
   LCD_X_SPI_Write_DATA(x1);
   LCD_X_SPI_Write_DATA(x2>>8);
   LCD_X_SPI_Write_DATA(x2);
  
   LCD_X_SPI_Write_CMD(0x2b);
   LCD_X_SPI_Write_DATA(y1>>8);
   LCD_X_SPI_Write_DATA(y1);
   LCD_X_SPI_Write_DATA(y2>>8);
   LCD_X_SPI_Write_DATA(y2);

   LCD_X_SPI_Write_CMD(0x2C);

}

void LCD_DrawPoint(int x,int y)
{
	Address_set(x,y,x,y); 
	LCD_WR_DATA(0xF800); 	    
} 


///*********************************************************************

/*********************************************************************
*
*       LCD_X_SPI_Write_DATA
*
* Purpose:
*   Write data to controller
*/

void LCD_X_SPI_Multiple_Read_DATA(U8 *dat, int byts)
{
	SSP1_CS_Low();
	DRIVER_MASTER_SPI.Receive(dat, byts);
	while (!isTransferCompleted)
        {
        }
	SSP1_CS_High();
}

U8 spi_receive()
{
	isTransferCompleted = false;
  isMasterOnReceive = true;
	DRIVER_MASTER_SPI.Receive(masterRxData, 1);
        while (!isTransferCompleted)
        {
        }					
	return (masterRxData[0]);
}

void LCD_X_SPI_Multiple_Write_DATA( U8 *dat, int byts)
{
	unsigned int i;
	//masterTxData[0] = *dat;
	SSP1_CS_Low();
	DRIVER_MASTER_SPI.Send(dat, byts);
	//Chip_SSP_RWFrames_Blocking(LPC_SSP, &xf_setup);
	while (!isTransferCompleted)
        {
        }

        isTransferCompleted = false;
        isMasterOnReceive = true;
				
	SSP1_CS_High();
}
void LCD_X_SPI_Write_DATA (U8 dat) {
	
	unsigned int i;
	masterTxData[0] = dat;
	SSP1_CS_Low();
	DRIVER_MASTER_SPI.Send(masterTxData, 1);
	//Chip_SSP_RWFrames_Blocking(LPC_SSP, &xf_setup);
	while (!isTransferCompleted)
        {
        }
        isTransferCompleted = false;
        isMasterOnReceive = true;
	SSP1_CS_High();
	//xf_setup.tx_cnt = 0;
}

void LCD_X_SPI_Write_CMD (U8 cmd) {
	unsigned int i;
	masterTxData[0] = cmd;
	SSP1_CS_Low();
	TFT_DC_Pin_Low();
	DRIVER_MASTER_SPI.Send(masterTxData, 1);
	while (!isTransferCompleted)
        {
        }
        isTransferCompleted = false;
        isMasterOnReceive = true;
	TFT_DC_Pin_High();
	SSP1_CS_High();
}

void LCD_X_SPI_Write_CMD_readid (U8 cmd) {
	unsigned int i;
	U8 h_byte, l_byte;
	masterTxData[0] = cmd;
	SSP1_CS_Low();
	TFT_DC_Pin_Low();
	DRIVER_MASTER_SPI.Send(masterTxData, 1);
	while (!isTransferCompleted)
        {
        }
        isTransferCompleted = false;
        isMasterOnReceive = true;
				
	TFT_DC_Pin_High();
	SSP1_CS_High();
				
	SSP1_CS_Low();
	h_byte = spi_receive();
	l_byte = spi_receive();
	SSP1_CS_High();
}


uint16_t lcdReadRegister(uint16_t reg) {
  LCD_X_SPI_Write_CMD_readid(reg);
}


uint16_t lcdReadID() {
  return lcdReadRegister(0x04);
}

/*************************** End of file ****************************/
